@@ -1,8 +1,9 @@
 """Top-level package for the yaxai project."""
 
-from .yax import AgentsmdBuildConfig, Yax
+from .yax import AgentsmdBuildConfig, CatalogBuildConfig, Yax
 
 __all__ = [
     "AgentsmdBuildConfig",
+    "CatalogBuildConfig",
     "Yax",
 ]
